@@ -199,6 +199,33 @@ class ExecutionFramework(Scheduler):
             )
             time.sleep(10)
 
+    def reconcile_task(self, task_config):
+        task_id = task_config.task_id
+        with self._lock:
+            if task_id in self.task_metadata:
+                md = self.task_metadata[task_id]
+                self.task_metadata = self.task_metadata.set(
+                    task_id,
+                    md.set(
+                        task_state='TASK_RECONCILING',
+                        task_state_history=md.task_state_history.set(
+                            'TASK_RECONCILING', time.time()),
+                    )
+                )
+            else:
+                log.info(f'Adding {task_id} to metadata for reconciliation')
+                self.task_metadata = self.task_metadata.set(
+                    task_id,
+                    TaskMetadata(
+                        task_config=task_config,
+                        task_state='TASK_RECONCILING',
+                        task_state_history=m(TASK_RECONCILING=time.time()),
+                    ),
+                )
+        self._reconcile_tasks([
+            Dict({'task_id': Dict({'value': task_id})})
+        ])
+
     def _reconcile_tasks(self, tasks_to_reconcile):
         if time.time() < self._reconcile_tasks_at:
             return
